@@ -50,13 +50,9 @@ class CfnMicrosoftAD(
         name: str,
         password: str,
         vpc_settings: typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable],
-        create_alias: typing.Optional[
-            typing.Union[bool, aws_cdk.core.IResolvable]
-        ] = None,
+        create_alias: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         edition: typing.Optional[str] = None,
-        enable_sso: typing.Optional[
-            typing.Union[bool, aws_cdk.core.IResolvable]
-        ] = None,
+        enable_sso: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         short_name: typing.Optional[str] = None,
     ) -> None:
         """Create a new ``AWS::DirectoryService::MicrosoftAD``.
@@ -83,34 +79,6 @@ class CfnMicrosoftAD(
 
         jsii.create(CfnMicrosoftAD, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnMicrosoftAD":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -338,16 +306,10 @@ class CfnMicrosoftADProps:
         *,
         name: str,
         password: str,
-        vpc_settings: typing.Union[
-            "CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable
-        ],
-        create_alias: typing.Optional[
-            typing.Union[bool, aws_cdk.core.IResolvable]
-        ] = None,
+        vpc_settings: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable],
+        create_alias: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         edition: typing.Optional[str] = None,
-        enable_sso: typing.Optional[
-            typing.Union[bool, aws_cdk.core.IResolvable]
-        ] = None,
+        enable_sso: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         short_name: typing.Optional[str] = None,
     ) -> None:
         """Properties for defining a ``AWS::DirectoryService::MicrosoftAD``.
@@ -481,13 +443,9 @@ class CfnSimpleAD(
         password: str,
         size: str,
         vpc_settings: typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"],
-        create_alias: typing.Optional[
-            typing.Union[bool, aws_cdk.core.IResolvable]
-        ] = None,
+        create_alias: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         description: typing.Optional[str] = None,
-        enable_sso: typing.Optional[
-            typing.Union[bool, aws_cdk.core.IResolvable]
-        ] = None,
+        enable_sso: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         short_name: typing.Optional[str] = None,
     ) -> None:
         """Create a new ``AWS::DirectoryService::SimpleAD``.
@@ -516,34 +474,6 @@ class CfnSimpleAD(
 
         jsii.create(CfnSimpleAD, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnSimpleAD":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -787,16 +717,10 @@ class CfnSimpleADProps:
         name: str,
         password: str,
         size: str,
-        vpc_settings: typing.Union[
-            aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"
-        ],
-        create_alias: typing.Optional[
-            typing.Union[bool, aws_cdk.core.IResolvable]
-        ] = None,
+        vpc_settings: typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"],
+        create_alias: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         description: typing.Optional[str] = None,
-        enable_sso: typing.Optional[
-            typing.Union[bool, aws_cdk.core.IResolvable]
-        ] = None,
+        enable_sso: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         short_name: typing.Optional[str] = None,
     ) -> None:
         """Properties for defining a ``AWS::DirectoryService::SimpleAD``.
